@@ -85,8 +85,7 @@ export class ActionSecretStack extends Stack {
 
     new ActionSecret(this, 'GitHubActionSecret', {
       githubTokenSecret,
-      repositoryName: 'cdk-github',
-      repositoryOwner: 'wtfjoke',
+      repository: { name: 'cdk-github', owner: 'wtfjoke' },
       repositorySecretName: 'A_RANDOM_GITHUB_SECRET',
       sourceSecret,
     });
@@ -110,8 +109,7 @@ export class ActionEnvironmentSecretStack extends Stack {
     new ActionEnvironmentSecret(this, 'GitHubActionEnvironmentSecret', {
       githubTokenSecret,
       environment: 'dev',
-      repositoryName: 'cdk-github',
-      repositoryOwner: 'wtfjoke',
+      repository: { name: 'cdk-github', owner: 'wtfjoke' },
       repositorySecretName: 'A_RANDOM_GITHUB_SECRET',
       sourceSecret,
     });
@@ -185,10 +183,9 @@ class ActionEnvironmentSecret(
         *,
         environment: builtins.str,
         github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
-        repository_name: builtins.str,
+        repository: "IGitHubRepository",
         repository_secret_name: builtins.str,
         source_secret: aws_cdk.aws_secretsmanager.ISecret,
-        repository_owner: typing.Optional[builtins.str] = None,
         source_secret_json_field: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -196,10 +193,9 @@ class ActionEnvironmentSecret(
         :param id: -
         :param environment: (experimental) The GithHub environment name which the secret should be stored in.
         :param github_token_secret: (experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
-        :param repository_name: (experimental) The GitHub repository name.
+        :param repository: (experimental) The GitHub repository information (owner and name).
         :param repository_secret_name: (experimental) The GitHub secret name to be stored.
         :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
-        :param repository_owner: (experimental) The GitHub repository owner. Default: - user account which owns the token
         :param source_secret_json_field: (experimental) The key of a JSON field to retrieve in sourceSecret. This can only be used if the secret stores a JSON object. Default: - returns all the content stored in the Secrets Manager secret.
 
         :stability: experimental
@@ -207,10 +203,9 @@ class ActionEnvironmentSecret(
         props = ActionEnvironmentSecretProps(
             environment=environment,
             github_token_secret=github_token_secret,
-            repository_name=repository_name,
+            repository=repository,
             repository_secret_name=repository_secret_name,
             source_secret=source_secret,
-            repository_owner=repository_owner,
             source_secret_json_field=source_secret_json_field,
         )
 
@@ -223,10 +218,9 @@ class ActionEnvironmentSecret(
     name_mapping={
         "environment": "environment",
         "github_token_secret": "githubTokenSecret",
-        "repository_name": "repositoryName",
+        "repository": "repository",
         "repository_secret_name": "repositorySecretName",
         "source_secret": "sourceSecret",
-        "repository_owner": "repositoryOwner",
         "source_secret_json_field": "sourceSecretJsonField",
     },
 )
@@ -236,19 +230,17 @@ class ActionEnvironmentSecretProps:
         *,
         environment: builtins.str,
         github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
-        repository_name: builtins.str,
+        repository: "IGitHubRepository",
         repository_secret_name: builtins.str,
         source_secret: aws_cdk.aws_secretsmanager.ISecret,
-        repository_owner: typing.Optional[builtins.str] = None,
         source_secret_json_field: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param environment: (experimental) The GithHub environment name which the secret should be stored in.
         :param github_token_secret: (experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
-        :param repository_name: (experimental) The GitHub repository name.
+        :param repository: (experimental) The GitHub repository information (owner and name).
         :param repository_secret_name: (experimental) The GitHub secret name to be stored.
         :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
-        :param repository_owner: (experimental) The GitHub repository owner. Default: - user account which owns the token
         :param source_secret_json_field: (experimental) The key of a JSON field to retrieve in sourceSecret. This can only be used if the secret stores a JSON object. Default: - returns all the content stored in the Secrets Manager secret.
 
         :stability: experimental
@@ -256,12 +248,10 @@ class ActionEnvironmentSecretProps:
         self._values: typing.Dict[str, typing.Any] = {
             "environment": environment,
             "github_token_secret": github_token_secret,
-            "repository_name": repository_name,
+            "repository": repository,
             "repository_secret_name": repository_secret_name,
             "source_secret": source_secret,
         }
-        if repository_owner is not None:
-            self._values["repository_owner"] = repository_owner
         if source_secret_json_field is not None:
             self._values["source_secret_json_field"] = source_secret_json_field
 
@@ -286,14 +276,14 @@ class ActionEnvironmentSecretProps:
         return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
 
     @builtins.property
-    def repository_name(self) -> builtins.str:
-        '''(experimental) The GitHub repository name.
+    def repository(self) -> "IGitHubRepository":
+        '''(experimental) The GitHub repository information (owner and name).
 
         :stability: experimental
         '''
-        result = self._values.get("repository_name")
-        assert result is not None, "Required property 'repository_name' is missing"
-        return typing.cast(builtins.str, result)
+        result = self._values.get("repository")
+        assert result is not None, "Required property 'repository' is missing"
+        return typing.cast("IGitHubRepository", result)
 
     @builtins.property
     def repository_secret_name(self) -> builtins.str:
@@ -315,17 +305,6 @@ class ActionEnvironmentSecretProps:
         assert result is not None, "Required property 'source_secret' is missing"
         return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
 
-    @builtins.property
-    def repository_owner(self) -> typing.Optional[builtins.str]:
-        '''(experimental) The GitHub repository owner.
-
-        :default: - user account which owns the token
-
-        :stability: experimental
-        '''
-        result = self._values.get("repository_owner")
-        return typing.cast(typing.Optional[builtins.str], result)
-
     @builtins.property
     def source_secret_json_field(self) -> typing.Optional[builtins.str]:
         '''(experimental) The key of a JSON field to retrieve in sourceSecret.
@@ -366,30 +345,27 @@ class ActionSecret(
         id: builtins.str,
         *,
         github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
-        repository_name: builtins.str,
+        repository: "IGitHubRepository",
         repository_secret_name: builtins.str,
         source_secret: aws_cdk.aws_secretsmanager.ISecret,
-        repository_owner: typing.Optional[builtins.str] = None,
         source_secret_json_field: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
         :param github_token_secret: (experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
-        :param repository_name: (experimental) The GitHub repository name.
+        :param repository: (experimental) The GitHub repository information (owner and name).
         :param repository_secret_name: (experimental) The GitHub secret name to be stored.
         :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
-        :param repository_owner: (experimental) The GitHub repository owner. Default: - user account which owns the token
         :param source_secret_json_field: (experimental) The key of a JSON field to retrieve in sourceSecret. This can only be used if the secret stores a JSON object. Default: - returns all the content stored in the Secrets Manager secret.
 
         :stability: experimental
         '''
         props = ActionSecretProps(
             github_token_secret=github_token_secret,
-            repository_name=repository_name,
+            repository=repository,
             repository_secret_name=repository_secret_name,
             source_secret=source_secret,
-            repository_owner=repository_owner,
             source_secret_json_field=source_secret_json_field,
         )
 
@@ -401,10 +377,9 @@ class ActionSecret(
     jsii_struct_bases=[],
     name_mapping={
         "github_token_secret": "githubTokenSecret",
-        "repository_name": "repositoryName",
+        "repository": "repository",
         "repository_secret_name": "repositorySecretName",
         "source_secret": "sourceSecret",
-        "repository_owner": "repositoryOwner",
         "source_secret_json_field": "sourceSecretJsonField",
     },
 )
@@ -413,30 +388,26 @@ class ActionSecretProps:
         self,
         *,
         github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
-        repository_name: builtins.str,
+        repository: "IGitHubRepository",
         repository_secret_name: builtins.str,
         source_secret: aws_cdk.aws_secretsmanager.ISecret,
-        repository_owner: typing.Optional[builtins.str] = None,
         source_secret_json_field: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param github_token_secret: (experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
-        :param repository_name: (experimental) The GitHub repository name.
+        :param repository: (experimental) The GitHub repository information (owner and name).
         :param repository_secret_name: (experimental) The GitHub secret name to be stored.
         :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
-        :param repository_owner: (experimental) The GitHub repository owner. Default: - user account which owns the token
         :param source_secret_json_field: (experimental) The key of a JSON field to retrieve in sourceSecret. This can only be used if the secret stores a JSON object. Default: - returns all the content stored in the Secrets Manager secret.
 
         :stability: experimental
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "github_token_secret": github_token_secret,
-            "repository_name": repository_name,
+            "repository": repository,
             "repository_secret_name": repository_secret_name,
             "source_secret": source_secret,
         }
-        if repository_owner is not None:
-            self._values["repository_owner"] = repository_owner
         if source_secret_json_field is not None:
             self._values["source_secret_json_field"] = source_secret_json_field
 
@@ -451,14 +422,14 @@ class ActionSecretProps:
         return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
 
     @builtins.property
-    def repository_name(self) -> builtins.str:
-        '''(experimental) The GitHub repository name.
+    def repository(self) -> "IGitHubRepository":
+        '''(experimental) The GitHub repository information (owner and name).
 
         :stability: experimental
         '''
-        result = self._values.get("repository_name")
-        assert result is not None, "Required property 'repository_name' is missing"
-        return typing.cast(builtins.str, result)
+        result = self._values.get("repository")
+        assert result is not None, "Required property 'repository' is missing"
+        return typing.cast("IGitHubRepository", result)
 
     @builtins.property
     def repository_secret_name(self) -> builtins.str:
@@ -480,17 +451,6 @@ class ActionSecretProps:
         assert result is not None, "Required property 'source_secret' is missing"
         return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
 
-    @builtins.property
-    def repository_owner(self) -> typing.Optional[builtins.str]:
-        '''(experimental) The GitHub repository owner.
-
-        :default: - user account which owns the token
-
-        :stability: experimental
-        '''
-        result = self._values.get("repository_owner")
-        return typing.cast(typing.Optional[builtins.str], result)
-
     @builtins.property
     def source_secret_json_field(self) -> typing.Optional[builtins.str]:
         '''(experimental) The key of a JSON field to retrieve in sourceSecret.
@@ -779,6 +739,80 @@ class GitHubResourceProps:
         )
 
 
+@jsii.interface(jsii_type="cdk-github.IGitHubRepository")
+class IGitHubRepository(typing_extensions.Protocol):
+    '''
+    :stability: experimental
+    '''
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="name")
+    def name(self) -> builtins.str:
+        '''(experimental) The GitHub repository name.
+
+        :stability: experimental
+        '''
+        ...
+
+    @name.setter
+    def name(self, value: builtins.str) -> None:
+        ...
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="owner")
+    def owner(self) -> typing.Optional[builtins.str]:
+        '''(experimental) The GitHub repository owner.
+
+        :default: - user account which owns the personal access token
+
+        :stability: experimental
+        '''
+        ...
+
+    @owner.setter
+    def owner(self, value: typing.Optional[builtins.str]) -> None:
+        ...
+
+
+class _IGitHubRepositoryProxy:
+    '''
+    :stability: experimental
+    '''
+
+    __jsii_type__: typing.ClassVar[str] = "cdk-github.IGitHubRepository"
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="name")
+    def name(self) -> builtins.str:
+        '''(experimental) The GitHub repository name.
+
+        :stability: experimental
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "name"))
+
+    @name.setter
+    def name(self, value: builtins.str) -> None:
+        jsii.set(self, "name", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="owner")
+    def owner(self) -> typing.Optional[builtins.str]:
+        '''(experimental) The GitHub repository owner.
+
+        :default: - user account which owns the personal access token
+
+        :stability: experimental
+        '''
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "owner"))
+
+    @owner.setter
+    def owner(self, value: typing.Optional[builtins.str]) -> None:
+        jsii.set(self, "owner", value)
+
+# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
+typing.cast(typing.Any, IGitHubRepository).__jsii_proxy_class__ = lambda : _IGitHubRepositoryProxy
+
+
 __all__ = [
     "ActionEnvironmentSecret",
     "ActionEnvironmentSecretProps",
@@ -786,6 +820,7 @@ __all__ = [
     "ActionSecretProps",
     "GitHubResource",
     "GitHubResourceProps",
+    "IGitHubRepository",
 ]
 
 publication.publish()
